Install
=======

Highpymath is an Python Module and you can install him on following Ways.

CPython
=======

pip (stable version)
--------------------

.. code-block:: bash

   python3 -m pip install highpymath

pip (newest version) via git
----------------------------

.. code-block:: bash

   python3 -m pip install git+https://github.com/pyrootcpp/highpymath

pip (newest version) via archive
--------------------------------

.. code-block:: bash

   python3 -m pip install https://github.com/pyrootcpp/highpymath/archive/master.zip

pypy3
=====

pip (stable version)
--------------------

.. code-block:: bash

   pypy3 -m pip install highpymath

pip (newest version) via git
----------------------------

.. code-block:: bash

   pypy3 -m pip install git+https://github.com/pyrootcpp/highpymath

pip (newest version) via archive
--------------------------------

.. code-block:: bash

   pypy3 -m pip install https://github.com/pyrootcpp/highpymath/archive/master.zip
